@@ -1,11 +1,3 @@
-/*
- * VegaFusion
- * Copyright (C) 2022 VegaFusion Technologies LLC
- *
- * This program is distributed under multiple licenses.
- * Please consult the license documentation provided alongside
- * this program the details of the active license.
- */
 use crate::error::Result;
 use crate::expression::column_usage::{ColumnUsage, GetDatasetsColumnUsage, VlSelectionFields};
 use crate::expression::parser::parse;
@@ -65,4 +57,21 @@ impl TransformSpecTrait for FormulaTransformSpec {
             TransformColumns::Unknown
         }
     }
+
+    fn local_datetime_columns_produced(
+        &self,
+        input_local_datetime_columns: &[String],
+    ) -> Vec<String> {
+        // Keep input local datetime columns as formula passes through all input columns
+        let mut output_local_datetime_columns = Vec::from(input_local_datetime_columns);
+
+        // Try to determine whether formula expression will generate a local datetime column.
+        // We don't have full type info so this isn't exact, but we can capture the most common
+        // local datetime expressions.
+        if self.expr.starts_with("toDate") || self.expr.starts_with("datetime") {
+            output_local_datetime_columns.push(self.as_.clone());
+        }
+
+        output_local_datetime_columns
+    }
 }
