@@ -1,11 +1,3 @@
-/*
- * VegaFusion
- * Copyright (C) 2022 VegaFusion Technologies LLC
- *
- * This program is distributed under multiple licenses.
- * Please consult the license documentation provided alongside
- * this program the details of the active license.
- */
 use vegafusion_core::error::{Result, VegaFusionError};
 use vegafusion_core::proto::gen::expression::expression::Expr;
 use vegafusion_core::proto::gen::expression::{ConditionalExpression, Expression};
@@ -28,7 +20,7 @@ pub fn if_fn(arguments: &[Expression]) -> Result<Expression> {
             span: None,
         })
     } else {
-        Err(VegaFusionError::compilation(&format!(
+        Err(VegaFusionError::compilation(format!(
             "The if function requires exactly 3 arguments. Received {}",
             arguments.len()
         )))
