@@ -9,7 +9,7 @@ pub fn to_number_transform(args: &[Expr], schema: &DFSchema) -> Result<Expr> {
         let arg = args[0].clone();
         let dtype = arg
             .get_type(schema)
-            .with_context(|| format!("Failed to infer type of expression: {:?}", arg))?;
+            .with_context(|| format!("Failed to infer type of expression: {arg:?}"))?;
 
         if !is_numeric_datatype(&dtype) {
             cast_to(arg, &DataType::Float64, schema)
