@@ -225,7 +225,9 @@ mod test_aggregate_with_nulls {
         case(AggregateOpSpec::Count),
         case(AggregateOpSpec::Valid),
         case(AggregateOpSpec::Missing),
-        case(AggregateOpSpec::Distinct)
+        case(AggregateOpSpec::Distinct),
+        case(AggregateOpSpec::Min),
+        case(AggregateOpSpec::Max)
     )]
     fn test(op: AggregateOpSpec) {
         let dataset = VegaFusionTable::from_json(
@@ -269,3 +271,60 @@ mod test_aggregate_with_nulls {
         );
     }
 }
+
+mod test_aggregate_strings {
+    use crate::*;
+    use serde_json::json;
+    use vegafusion_core::data::table::VegaFusionTable;
+
+    #[rstest(
+        op,
+        case(AggregateOpSpec::Count),
+        case(AggregateOpSpec::Valid),
+        case(AggregateOpSpec::Missing),
+        case(AggregateOpSpec::Distinct),
+        case(AggregateOpSpec::Min),
+        case(AggregateOpSpec::Max)
+    )]
+    fn test(op: AggregateOpSpec) {
+        let dataset = VegaFusionTable::from_json(
+            &json!(
+                [
+                    {"a": 1, "b": "A"},
+                    {"a": 1, "b": "BB"},
+                    {"a": 2, "b": "CCC"},
+                    {"a": 2, "b": "CCC"},
+                    {"a": 2, "b": "DDDD"}
+                ]
+            ),
+            1024,
+        )
+        .unwrap();
+
+        let aggregate_spec = AggregateTransformSpec {
+            groupby: vec![Field::String("a".to_string())],
+            fields: Some(vec![Some(Field::String("b".to_string()))]),
+            ops: Some(vec![op]),
+            as_: None,
+            cross: None,
+            drop: None,
+            key: None,
+            extra: Default::default(),
+        };
+        let transform_specs = vec![TransformSpec::Aggregate(aggregate_spec)];
+
+        let comp_config = Default::default();
+
+        let eq_config = TablesEqualConfig {
+            row_order: true,
+            ..Default::default()
+        };
+
+        check_transform_evaluation(
+            &dataset,
+            transform_specs.as_slice(),
+            &comp_config,
+            &eq_config,
+        );
+    }
+}
